@@ -1,15 +1,15 @@
 # dycow
 from dycow import (
+    VERSION,
+    BaseHTTPRequestHandler,
+    HTTPServer,
+    argv,
+    json_loads,
     path,
     system,
     urlparse,
-    json_loads,
-    BaseHTTPRequestHandler,
-    argv,
-    HTTPServer,
-    VERSION
 )
-from dycow.utils import parse_conf_file, cmd_output_to_res
+from dycow.utils import cmd_output_to_res, parse_conf_file
 
 CONF_FILE = ""
 REQS = []
@@ -18,7 +18,7 @@ REQS = []
 class S(BaseHTTPRequestHandler):
     def _set_response(self):
         self.send_response(200)
-        self.send_header('Content-type', 'text/html')
+        self.send_header("Content-type", "text/html")
         self.end_headers()
 
     def get_queries(self):
@@ -29,7 +29,7 @@ class S(BaseHTTPRequestHandler):
         for p in urlparse(self.path).query.split("&"):
             try:
                 q_params.append({"key": p.split("=")[0], "value": p.split("=")[1]})
-            except Exception as es:
+            except Exception:
                 pass
 
         return q_params
@@ -41,34 +41,55 @@ class S(BaseHTTPRequestHandler):
         """
         res = ""
         for r in REQS:
-            if (r["type"] == "GET" or r["type"] == "POST") \
-                    and str(self.path).split("?")[0] == r["url_path"].split("?")[0]:
+            if (r["type"] == "GET" or r["type"] == "POST") and str(self.path).split(
+                "?"
+            )[0] == r["url_path"].split("?")[0]:
 
                 res = r["res"]
                 # To create / empty the file
-                open('./out', 'w').close()
-                if body_params is not None and bool(body_params) and r["type"] == "POST":
+                open("./out", "w").close()
+                if (
+                    body_params is not None
+                    and bool(body_params)
+                    and r["type"] == "POST"
+                ):
                     # it's the good link
                     for cmd in r["command"]:
                         for pr in r["body_params"]:
-                            cmd = cmd.replace("#{}#".format(pr), body_params[pr]) if "#"+pr+"#" in cmd else ""
+                            cmd = (
+                                cmd.replace("#{}#".format(pr), body_params[pr])
+                                if "#" + pr + "#" in cmd
+                                else ""
+                            )
                         system(cmd + " >> out")
 
                     res = cmd_output_to_res(res)
 
                     for p in r["body_params"]:
-                        res = res.replace("#{}#".format(p), body_params[p]) if "#"+p+"#" in res else res
+                        res = (
+                            res.replace("#{}#".format(p), body_params[p])
+                            if "#" + p + "#" in res
+                            else res
+                        )
                 else:
                     # it's the good link
                     for cmd in r["command"]:
                         for p in q_params:
-                            cmd = cmd.replace("#{}#".format(p["key"]), p["value"]) if "#"+p["key"]+"#" in cmd else ""
+                            cmd = (
+                                cmd.replace("#{}#".format(p["key"]), p["value"])
+                                if "#" + p["key"] + "#" in cmd
+                                else ""
+                            )
                         system(cmd + " >> out")
 
                     res = cmd_output_to_res(res)
 
                     for p in q_params:
-                        res = res.replace("#{}#".format(p["key"]), p["value"]) if "#" + p["key"] + "#" in res else res
+                        res = (
+                            res.replace("#{}#".format(p["key"]), p["value"])
+                            if "#" + p["key"] + "#" in res
+                            else res
+                        )
 
         return res
 
@@ -77,23 +98,27 @@ class S(BaseHTTPRequestHandler):
         The built in GET handler
         """
         self._set_response()
-        self.wfile.write("{}".format(self.execute_return_res(self.get_queries())).encode('utf-8'))
+        self.wfile.write(
+            "{}".format(self.execute_return_res(self.get_queries())).encode("utf-8")
+        )
 
     def do_POST(self):
         """
         The built in POST handler
         """
         self._set_response()
-        self.wfile.write("{}".format(
-            self.execute_return_res(
-                self.get_queries(),
-                json_loads(
-                    self.rfile.read(
-                        int(self.headers['Content-Length'])
-                    ).decode('utf-8')
+        self.wfile.write(
+            "{}".format(
+                self.execute_return_res(
+                    self.get_queries(),
+                    json_loads(
+                        self.rfile.read(int(self.headers["Content-Length"])).decode(
+                            "utf-8"
+                        )
+                    ),
                 )
-            )
-        ).encode('utf-8'))
+            ).encode("utf-8")
+        )
 
 
 def run(server_class=HTTPServer, handler_class=S, port=8080):
@@ -101,24 +126,32 @@ def run(server_class=HTTPServer, handler_class=S, port=8080):
     The runner function
     """
     print("- " * 30)
-    httpd = server_class(('', port), handler_class)
-    print('[-] Starting dycow instance...\n[-] On port<{}>, conf<{}>...\n'.format(port, CONF_FILE))
+    httpd = server_class(("", port), handler_class)
+    print(
+        "[-] Starting dycow instance...\n[-] On port<{}>, conf<{}>...\n".format(
+            port, CONF_FILE
+        )
+    )
     try:
         httpd.serve_forever()
     except KeyboardInterrupt:
         pass
     httpd.server_close()
 
-    print('[x] Stopping dycow...\n')
+    print("[x] Stopping dycow...\n")
     print("- " * 30)
 
 
 def help_center():
-    print("[-] dycow v" + VERSION + ".\n[-] Help center !\n[x] Run : dw <port> <conf-file> \n"
-          "[x] Documentation online https://github.com/sanix-darker/dycow")
+    print(
+        "[-] dycow v"
+        + VERSION
+        + ".\n[-] Help center !\n[x] Run : dw <port> <conf-file> \n"
+        "[x] Documentation online https://github.com/sanix-darker/dycow"
+    )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     if len(argv) == 3:
         CONF_FILE = argv[2]
         # We check if a config file have been provide
